%global github_owner    roboptim
%global github_name     roboptim-core
%global github_version  3.1
%global github_commit   9f826bdc2513873e4b67a1d01cda8f78d1fe65b7

%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}}
%{!?_licensedir:%global license %%doc}

Name: roboptim-core
Version: 3.1
Release: 3%{?dist}
Summary: The RobOptim core C++ library

Group: Development/Libraries
License: LGPLv3+
URL: http://www.roboptim.net/
# Project uses submodules, github auto-generated tarballs do not include
# these
Source0:        https://github.com/%{github_owner}/%{github_name}/releases/download/v%{github_version}/%{github_name}-%{github_version}.tar.bz2
# Upstream forces lib suffix to be lib/ , remove this. See:
# https://github.com/roboptim/roboptim-core/pull/101
# https://github.com/jrl-umi3218/jrl-cmakemodules/commit/fba6aef9c4cddcc9728192bd17d0c1906a9b2dcd
Patch0:         roboptim-core-3.1-libdir.patch
# Fix various issues causing test failures on 32-bit
# https://github.com/roboptim/roboptim-core/issues/102
Patch1:         https://github.com/roboptim/roboptim-core/commit/8b03203596548e36a41f02d7f48856d67e077da8.patch

BuildRequires: boost-devel, libtool-ltdl-devel
# Require Doxygen and its dependencies. After 3.1, uses 'Mathjax' instead
# of tex.
BuildRequires: doxygen, tex(latex), tex(dvips), /usr/bin/gs
BuildRequires: cmake
BuildRequires: pkgconfig
BuildRequires: pkgconfig(eigen3) >= 3.2.0
BuildRequires: pkgconfig(liblog4cxx) >= 0.10.0


%description
RobOptim provide C++ numerical optimization libraries for robotics.
RobOptim core focuses on providing abstractions for optimization problem
definition and infrastructure to allow the use of existing solvers as
a back-end.


%package devel
Summary: The Roboptim core headers and development-related files
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}, boost-devel, libtool-ltdl-devel
# pkg-config dependency is detected automatically on Fedora.
%description devel
Headers and shared object symlinks for the RobOptim core C++ library.


%package doc
Summary: The RobOptim core documentation
Group: Documentation
Requires: %{name} = %{version}-%{release}
%description doc
Documentation for the RobOptim core library.


%prep
%setup -q
%patch0 -p1
%patch1 -p1
# This should be in the tarball, but is missing:
# https://github.com/roboptim/roboptim-core/issues/103
echo "3.1" > .version


%build
%cmake .

#FIXME: should libraries have version numbers or not?
# LDFLAGS="-avoid-version"
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=%{buildroot}

# Install
install -cpm 644 AUTHORS CONTRIBUTING.md NEWS README.md THANKS TODO\
 $RPM_BUILD_ROOT%{_pkgdocdir}


%check
ctest -V %{?_smp_mflags}


%files
%license COPYING.LESSER
%doc %dir %{_pkgdocdir}

# for COPYING, INSTALL, AUTHORS, etc.
%doc %{_pkgdocdir}/[A-Z]*

# versioned shared library
%{_libdir}/*.so.*

# package whole directory:
# ``.so'' file is also needed as ltdl_openext does not consider
# versioned plug-ins.
%{_libdir}/%{name}/

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%files doc
%doc %{_pkgdocdir}/doxygen-html/

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%changelog
* Tue Jul 28 2015 Adam Williamson <awilliam@redhat.com> - 3.1-3
- backport upstream fixes for 32-bit test failure bugs
- drop EIGEN_DONT_ALIGN and re-enable tests for all arches

* Mon Jul 27 2015 Adam Williamson <awilliam@redhat.com> - 3.1-2
- adjust the libdir fix
- fix version identification (.version file missing from tarball)
- update URL

* Mon Jul 27 2015 Adam Williamson <awilliam@redhat.com> - 3.1-1
- update to latest release
- refresh spec for current standards
- patch an upstream issue with libdir location
- build with EIGEN_DONT_ALIGN to avoid suspicious test failures on i686

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.5-16
- rebuild for Boost 1.58

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.5-14
- Rebuild for boost 1.57.0

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 0.5-11
- Rebuild for boost 1.55.0

* Tue Aug 13 2013 Ralf Corsépius <corsepiu@fedoraproject.org> - 0.5-10
- Remove hard-coded -Werror (Add roboptim-core-0.5-werror.diff)
  F20FTBFS RHBZ#991900, F19FTBFS RHBZ#913839.
- Reflect docdir changes (RHBZ#993931).

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 0.5-8
- Rebuild for boost 1.54.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 0.5-7
- Rebuild for Boost-1.53.0

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-5
- Rebuilt for c++ ABI breakage

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jan 14 2010 Thomas Moulard <thomas.moulard@gmail.com> - 0.5-2
- Fix unowned directories problem.
- Fix documentation packaging rules.

* Wed Jan 13 2010 Thomas Moulard <thomas.moulard@gmail.com> - 0.5-1
- Fix plug-in path (now packaged properly in a subdirectory).
- Add missing build requirements (latex / dvips).
- Add missing requirements (boost-devel, libtool-ltdl-devel in roboptim-devel).
- Use "install -p" to preserve timestamps.
- Update to release 0.5.
- For more information see: https://bugzilla.redhat.com/show_bug.cgi?id=538820

* Thu Nov 12 2009 Thomas Moulard <thomas.moulard@gmail.com> - 0.3.28-1
- Fix rpmlint errors.
- Handle Autotools issues (add -avoid-version and --distable-static).

* Wed Nov 11 2009 Thomas Moulard <thomas.moulard@gmail.com> - 0.3-1
- initial work
